import {HttpException, HttpStatus, Injectable} from "@nestjs/common";
import {InjectRepository} from "@nestjs/typeorm";
import {Constants} from "src/utils/constants";
import {ResponseUtils} from "src/utils/response.utils";
import {CareerDetailsPageCmsRepository} from "./career-details-page-cms.repository";
import {UpdateCareerDetailsPageCmsDto} from "./dto/update-career-details-page-cms.dto";
import {CareerDetailsPageCmsEntity} from "./entities/career-details-page-cms.entity";
import {DoSpacesService} from "src/modules/SpacesModule/SpacesService/doSpacesService";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";

@Injectable()
export class CareerDetailsPageCmsService {
    constructor(
        @InjectRepository(CareerDetailsPageCmsRepository)
        private readonly repository: CareerDetailsPageCmsRepository,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
        dto: UpdateCareerDetailsPageCmsDto,
        files: {
            logo: UploadedMulterFileI
        }
    ): Promise<CareerDetailsPageCmsEntity | Error> {
        if (files && files.logo) {
            const logoData: any = await this.doSpaceService.uploadFile(files.logo[0], "CareerDetailsPageCMS/");
            dto.logo = logoData;
        }
        const isExists = await this.repository.find({isDeleted: false});
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CareerDetailsPageCmsEntity[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}