import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { TermsOfServiceCmsService } from "./terms-of-service-cms.service";
import { UpdateTermsOfServiceCmsDto } from "./dto/update-terms-of-service-cms.dto";
import {FileFieldsInterceptor} from "@nestjs/platform-express";
import {UploadedMulterFileI} from "../../SpacesModule/SpacesService";

@Controller({ path: "terms-of-service-cms", version: Constants.API_VERSION_1 })

export class TermsOfServiceCmsController {
    constructor(private readonly service: TermsOfServiceCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            {name: "logo", maxCount: 1}
        ]
    ))
    updateOrCreateData(
      @Body() dto: UpdateTermsOfServiceCmsDto,
      @UploadedFiles() files: {
          logo: UploadedMulterFileI
      }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
