import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateSiteSocialLinksDto } from "./dto/create-site-social-links.dto";
import { UpdateSiteSocialLinksDto } from "./dto/update-site-social-links.dto";
import { SiteSocialLinks } from "./entities/site-social-links.entity";

@EntityRepository(SiteSocialLinks)
export class SiteSocialLinksRepository extends Repository<SiteSocialLinks> {
    async createEntity(dto: CreateSiteSocialLinksDto): Promise<SiteSocialLinks | Error> {
        try {
            const { iconClassName, link } = dto;
            const entity = this.create({
                iconClassName,
                link
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<SiteSocialLinks | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateSiteSocialLinksDto): Promise<SiteSocialLinks | Error> {
        try {
            await this.update(id, {
                iconClassName: dto.iconClassName,
                link: dto.link
            });
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query : any): Promise<SiteSocialLinks[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(SiteSocialLinks)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if(updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch(e) {
            return e;
        }
    }
}